package myproject;

import org.apache.commons.lang.*;
import org.codehaus.plexus.context.*;
import org.codehaus.plexus.logging.Logger;
import org.codehaus.plexus.logging.console.*;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

/**
 * The classic Hello World App.
 */
public class HelloWorld {

  /**
     * Main method.
     *
     * @param args Not used
     */
    public static void main( String[] args )
    {
        String empty = null;
        Context context = new DefaultContext();
        ConsoleLogger consoleLogger = new ConsoleLogger( Logger.LEVEL_INFO, "console" );
        consoleLogger.info( "great it works" );
        if (StringUtils.isEmpty( empty ))
        {
            System.exit( 0 );
        }
        System.exit( 1 );
    } 
}